@@ -1,5 +1,5 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "outli" "0.3.0"
+(define-package "outli" "20251012.1930"
   "Org-like code outliner."
   '((emacs "27.1"))
   :url "https://github.com/jdtsmith/outli"
